@@ -17,7 +17,7 @@ class Deployment:
         self._compile_logs = logs
         if path:
             self.base_path = Path(path)
-            self.report_path = self.base_path / 'report.json'
+            self.report_path = self.base_path / Path('report.json')
         else:
             self.base_path = Path("")
             self.report_path = Path('report.json')
@@ -47,7 +47,7 @@ class Deployment:
     @property
     def compiled_files(self):
         if os.path.exists(self.base_path):
-            model_src = self.base_path / 'build'
+            model_src = self.base_path / Path('build')
             if model_src.exists():
                 files = []
                 # list all files recursively
